/**---------------------------------------------------------------------------

  Name         :  SUMP.h
  Description  :  SUMP protocol commands definition
  Author       :  Aleksander Borysiuk

  History      :  2014.08.03 - ver.1.0

------------------------------------------------------------------------------*/

#ifndef _SUMP_H_
#define _SUMP_H_

/* Public define -------------------------------------------------------------*/
// Standard SUMP protocol commands
// Short commands (length: 1B - opcode only)
#define SUMP_RESET           0x00      // reset the device
#define SUMP_RUN             0x01      // arm the trigger
#define SUMP_ID              0x02      // request for the device identification
#define SUMP_XON             0x11      // put transmitter out of pause mode
#define SUMP_XOFF            0x13      // put transmitter in pause mode

// Long commands (length: 5B - opcode and data)
#define SUMP_SET_TRG_MSK_S0  0xC0      // set trigger mask for stage 0
#define SUMP_SET_TRG_MSK_S1  0xC4      // set trigger mask for stage 1
#define SUMP_SET_TRG_MSK_S2  0xC8      // set trigger mask for stage 2
#define SUMP_SET_TRG_MSK_S3  0xCC      // set trigger mask for stage 3

#define SUMP_SET_TRG_VAL_S0  0xC1      // set trigger value for stage 0
#define SUMP_SET_TRG_VAL_S1  0xC5      // set trigger value for stage 1
#define SUMP_SET_TRG_VAL_S2  0xC9      // set trigger value for stage 2
#define SUMP_SET_TRG_VAL_S3  0xCD      // set trigger value for stage 3

#define SUMP_SET_TRG_CFG_S0  0xC2      // set trigger configuration for stage 0
#define SUMP_SET_TRG_CFG_S1  0xC6      // set trigger configuration for stage 1
#define SUMP_SET_TRG_CFG_S2  0xCA      // set trigger configuration for stage 2
#define SUMP_SET_TRG_CFG_S3  0xCE      // set trigger configuration for stage 3

#define SUMP_SET_DVDR        0x80      // set divider (fsmpl = fclk/(dvdr+1))
#define SUMP_SET_RD_CNT      0x81      // set read and delay count
#define SUMP_SET_FLAGS       0x82      // set flags

// Command 0x82 (SUMP_SET_FLAGS) flags
#define F_DMUX             (1 << 24)   // demux imput mode enable
#define F_FLTR             (1 << 25)   // filter input mode enable
#define F_DIS_GR0          (1 << 26)   // channel group 0 disable
#define F_DIS_GR1          (1 << 27)   // channel group 1 disable
#define F_DIS_GR2          (1 << 28)   // channel group 2 disable
#define F_DIS_GR3          (1 << 29)   // channel group 3 disable
#define F_EXT_CLK          (1 << 30)   // external sampling clock select
#define F_INV_CLK          (1 << 31)   // external sampling clock invert


// Extended SUMP protocol commands
// Short commands (length: 1B - opcode only)
#define SUMP_TEST            0x03      // trigger a self test pattern
#define SUMP_GET_MDATA       0x04      // get metadata
#define SUMP_STOP            0x05      // finish the current capture and dump the samples

// Command 0x04 (SUMP_GET_MDATA) keys
// Key 000xxxxb: null-terminated string, UTF-8 encoded
#define MDATA_END           0x00       // end of metadata
#define MDATA_DEV_NAME      0x01       // device name
#define MDATA_FPGA_VER      0x02       // version of the FPGA firmware
#define MDATA_AUX_VER       0x03       // nncillary version (PIC firmware)
// Key 001xxxxxb: 32-bit unsigned integer
#define MDATA_PROBES        0x20       // number of usable probes
#define MDATA_SMPL_MEM      0x21       // amount of sample memory available (bytes)
#define MDATA_RAM_MEM       0x22       // amount of dynamic memory available (bytes)
#define MDATA_MAX_FRQ       0x23       // maximum sample rate (Hz)
#define MDATA_PROTOCOL      0x24       // protocol version (0x00000002 - ver. 2.0.0.0)
// Key 010xxxxxb: 8-bit unsigned integer
#define MDATA_PROBES_SHRT   0x40       // number of usable probes (short)
#define MDATA_PROTOCOL_SHRT 0x41       // protocol version (short)

/* Public constants ----------------------------------------------------------*/
/* Public variables ----------------------------------------------------------*/
/* Public functions ----------------------------------------------------------*/

#endif
/*----------------------------- End of file ----------------------------------*/
